@@ -9,9 +9,14 @@ Rset = list("fancyvrb" = "true", "escapechar" = "`",
         "language" = "R", "basicstyle" = "{\\color{Rcolor}\\small}",
         "keywordstyle" = "{\\bf\\color{Rcolor}}",
         "commentstyle" = "{\\color{Rcomment}\\ttfamily\\itshape}",
-        "literate" = "{<-}{{$\\leftarrow$}}2{<<-}{{$\\twoheadleftarrow$}}2",
+        "literate" = paste("{<-}{{$\\leftarrow$}}2",
+                           "{<<-}{{$\\twoheadleftarrow$}}2",#"%\n",
+                           "{~}{{$\\sim$}}1", "{<=}{{$\\leq$}}2",#"%\n",
+                           "{>=}{{$\\geq$}}2", "{^}{{$\\scriptstyle\\wedge$}}1", sep=""),
+                     ## ~,^,<=, >= as suggested by Frank Harrell
         "alsoother" = "{$}", "alsoletter" = "{.<-}",
-        "otherkeywords" = "{!,!=,~,$,*,\\&,\\%/\\%,\\%*\\%,\\%\\%,<-,<<-,/}"        
+        "otherkeywords" = "{!,!=,~,$,*,\\&,\\%/\\%,\\%*\\%,\\%\\%,<-,<<-,/}",
+        "escapeinside" = "{(*}{*)}" ## as suggested by Frank Harrell
         ),
 Rdset = list("fancyvrb" = "true", "language" = "Rd", 
              "keywordstyle" = "{\\bf}",
